/**
 * Represents a financial position in a portfolio.
 */
export interface Position {

    /**
     * The symbol name of the asset
     */
    readonly symbol: string;

    /**
     * The total number of shares, not including open orders
     */
    readonly quantity: number;

    /**
     * The total dollar amount of the position
     */
    readonly marketValue: number;

    /**
     * The total cost basis
     */
    readonly costBasis: number;

    /**
     * The current asset price per share
     */
    readonly pricePerShare: number;
}

/**
 * Represents a portfolio of financial positions.
 */
export interface Portfolio {

    /**
     * An array of positions held in the portfolio.
     */
    readonly positions: Position[];
}

/**
 * A provider for fetching a portfolio.
 */
export interface PortfolioProvider {

    /**
     * Fetches the portfolio.
     * @returns A promise that resolves with the fetched portfolio.
     */
    readonly fetchPortfolio: () => Promise<Portfolio>;
}
