/**
 * Represents a stock quote.
 */
export interface Quote {

    /**
     * The symbol of the asset
     */
    readonly symbol: string;

    /**
     * The ask price of the asset
     */
    readonly askPrice: number;

    /**
     * The ask size of the asset
     */
    readonly askSize: number;

    /**
     * The bid price of the asset
     */
    readonly bidPrice: number;

    /**
     * The bid size of the asset
     */
    readonly bidSize: number;

    /**
     * The timestamp of the quote
     */
    readonly timeStamp: Date;
}

/**
 * A provider for fetching stock quotes.
 */
export interface QuoteProvider {

    /**
     * Fetches a quote for the given stock symbol.
     * @param symbol The stock symbol to fetch the quote for.
     * @returns A Promise that resolves to a Quote object.
     */
    readonly fetchQuote: (symbol: string) => Promise<Quote>;
}
